@@ -13,30 +13,30 @@ from archinstall.tui.types import Alignment, FrameProperties
 class NiriProfile(XorgProfile):
 	def __init__(self) -> None:
 		super().__init__(
-			"Niri",
+			'Niri',
 			ProfileType.WindowMgr,
 		)
 
-		self.custom_settings = {"seat_access": None}
+		self.custom_settings = {'seat_access': None}
 
 	@property
 	@override
 	def packages(self) -> list[str]:
 		additional = []
-		if seat := self.custom_settings.get("seat_access", None):
+		if seat := self.custom_settings.get('seat_access', None):
 			additional = [seat]
 
 		return [
-			"niri",
-			"alacritty",
-			"fuzzel",
-			"mako",
-			"xorg-xwayland",
-			"waybar",
-			"swaybg",
-			"swayidle",
-			"swaylock",
-			"xdg-desktop-portal-gnome",
+			'niri',
+			'alacritty',
+			'fuzzel',
+			'mako',
+			'xorg-xwayland',
+			'waybar',
+			'swaybg',
+			'swayidle',
+			'swaylock',
+			'xdg-desktop-portal-gnome',
 		] + additional
 
 	@property
@@ -47,32 +47,32 @@ class NiriProfile(XorgProfile):
 	@property
 	@override
 	def services(self) -> list[str]:
-		if pref := self.custom_settings.get("seat_access", None):
+		if pref := self.custom_settings.get('seat_access', None):
 			return [pref]
 		return []
 
 	def _ask_seat_access(self) -> None:
 		# need to activate seat service and add to seat group
-		header = tr("niri needs access to your seat (collection of hardware devices i.e. keyboard, mouse, etc)")
-		header += "\n" + tr("Choose an option to give niri access to your hardware") + "\n"
+		header = tr('niri needs access to your seat (collection of hardware devices i.e. keyboard, mouse, etc)')
+		header += '\n' + tr('Choose an option to give niri access to your hardware') + '\n'
 
 		items = [MenuItem(s.value, value=s) for s in SeatAccess]
 		group = MenuItemGroup(items, sort_items=True)
 
-		default = self.custom_settings.get("seat_access", None)
+		default = self.custom_settings.get('seat_access', None)
 		group.set_default_by_value(default)
 
 		result = SelectMenu[SeatAccess](
 			group,
 			header=header,
 			allow_skip=False,
-			frame=FrameProperties.min(tr("Seat access")),
+			frame=FrameProperties.min(tr('Seat access')),
 			alignment=Alignment.CENTER,
 		).run()
 
 		if result.type_ == ResultType.Selection:
 			if result.item() is not None:
-				self.custom_settings["seat_access"] = result.get_value().value
+				self.custom_settings['seat_access'] = result.get_value().value
 
 	@override
 	def do_on_select(self) -> None:
