@@ -20,18 +20,18 @@ from ..translationhandler import Language
 
 
 class PostInstallationAction(Enum):
-	EXIT = tr("Exit archinstall")
-	REBOOT = tr("Reboot system")
-	CHROOT = tr("chroot into installation for post-installation configurations")
+	EXIT = tr('Exit archinstall')
+	REBOOT = tr('Reboot system')
+	CHROOT = tr('chroot into installation for post-installation configurations')
 
 
 def ask_ntp(preset: bool = True) -> bool:
-	header = tr("Would you like to use automatic time synchronization (NTP) with the default time servers?\n") + "\n"
+	header = tr('Would you like to use automatic time synchronization (NTP) with the default time servers?\n') + '\n'
 	header += (
 		tr(
-			"Hardware time and other post-configuration steps might be required in order for NTP to work.\nFor more information, please check the Arch wiki",
+			'Hardware time and other post-configuration steps might be required in order for NTP to work.\nFor more information, please check the Arch wiki',
 		)
-		+ "\n"
+		+ '\n'
 	)
 
 	preset_val = MenuItem.yes() if preset else MenuItem.no()
@@ -53,12 +53,12 @@ def ask_ntp(preset: bool = True) -> bool:
 		case ResultType.Selection:
 			return result.item() == MenuItem.yes()
 		case _:
-			raise ValueError("Unhandled return type")
+			raise ValueError('Unhandled return type')
 
 
 def ask_hostname(preset: str | None = None) -> str | None:
 	result = EditMenu(
-		tr("Hostname"),
+		tr('Hostname'),
 		alignment=Alignment.CENTER,
 		allow_skip=True,
 		default_text=preset,
@@ -73,11 +73,11 @@ def ask_hostname(preset: str | None = None) -> str | None:
 				return None
 			return hostname
 		case ResultType.Reset:
-			raise ValueError("Unhandled result type")
+			raise ValueError('Unhandled result type')
 
 
 def ask_for_a_timezone(preset: str | None = None) -> str | None:
-	default = "UTC"
+	default = 'UTC'
 	timezones = list_timezones()
 
 	items = [MenuItem(tz, value=tz) for tz in timezones]
@@ -89,7 +89,7 @@ def ask_for_a_timezone(preset: str | None = None) -> str | None:
 		group,
 		allow_reset=True,
 		allow_skip=True,
-		frame=FrameProperties.min(tr("Timezone")),
+		frame=FrameProperties.min(tr('Timezone')),
 		alignment=Alignment.CENTER,
 	).run()
 
@@ -113,7 +113,7 @@ def ask_for_audio_selection(preset: AudioConfiguration | None = None) -> AudioCo
 		group,
 		allow_skip=True,
 		alignment=Alignment.CENTER,
-		frame=FrameProperties.min(tr("Audio")),
+		frame=FrameProperties.min(tr('Audio')),
 	).run()
 
 	match result.type_:
@@ -122,7 +122,7 @@ def ask_for_audio_selection(preset: AudioConfiguration | None = None) -> AudioCo
 		case ResultType.Selection:
 			return AudioConfiguration(audio=result.get_value())
 		case ResultType.Reset:
-			raise ValueError("Unhandled result type")
+			raise ValueError('Unhandled result type')
 
 
 def select_language(preset: str | None = None) -> str | None:
@@ -133,7 +133,7 @@ def select_language(preset: str | None = None) -> str | None:
 	# raise Deprecated("select_language() has been deprecated, use select_kb_layout() instead.")
 
 	# No need to translate this i feel, as it's a short lived message.
-	warn("select_language() is deprecated, use select_kb_layout() instead. select_language() will be removed in a future version")
+	warn('select_language() is deprecated, use select_kb_layout() instead. select_language() will be removed in a future version')
 
 	return select_kb_layout(preset)
 
@@ -147,9 +147,9 @@ def select_archinstall_language(languages: list[Language], preset: Language) ->
 	group = MenuItemGroup(items, sort_items=True)
 	group.set_focus_by_value(preset)
 
-	title = "NOTE: If a language can not displayed properly, a proper font must be set manually in the console.\n"
+	title = 'NOTE: If a language can not displayed properly, a proper font must be set manually in the console.\n'
 	title += 'All available fonts can be found in "/usr/share/kbd/consolefonts"\n'
-	title += "e.g. setfont LatGrkCyr-8x16 (to display latin/greek/cyrillic characters)\n"
+	title += 'e.g. setfont LatGrkCyr-8x16 (to display latin/greek/cyrillic characters)\n'
 
 	result = SelectMenu[Language](
 		group,
@@ -157,7 +157,7 @@ def select_archinstall_language(languages: list[Language], preset: Language) ->
 		allow_skip=True,
 		allow_reset=False,
 		alignment=Alignment.CENTER,
-		frame=FrameProperties.min(header=tr("Select language")),
+		frame=FrameProperties.min(header=tr('Select language')),
 	).run()
 
 	match result.type_:
@@ -166,7 +166,7 @@ def select_archinstall_language(languages: list[Language], preset: Language) ->
 		case ResultType.Selection:
 			return result.get_value()
 		case ResultType.Reset:
-			raise ValueError("Language selection not handled")
+			raise ValueError('Language selection not handled')
 
 
 def ask_additional_packages_to_install(
@@ -175,18 +175,18 @@ def ask_additional_packages_to_install(
 ) -> list[str]:
 	repositories |= {Repository.Core, Repository.Extra}
 
-	respos_text = ", ".join([r.value for r in repositories])
-	output = tr("Repositories: {}").format(respos_text) + "\n"
+	respos_text = ', '.join([r.value for r in repositories])
+	output = tr('Repositories: {}').format(respos_text) + '\n'
 
-	output += tr("Loading packages...")
+	output += tr('Loading packages...')
 	Tui.print(output, clear_screen=True)
 
 	packages = list_available_packages(tuple(repositories))
 	package_groups = PackageGroup.from_available_packages(packages)
 
 	# Additional packages (with some light weight error handling for invalid package names)
-	header = tr("Only packages such as base, base-devel, linux, linux-firmware, efibootmgr and optional profile packages are installed.") + "\n"
-	header += tr("Select any packages from the below list that should be installed additionally") + "\n"
+	header = tr('Only packages such as base, base-devel, linux, linux-firmware, efibootmgr and optional profile packages are installed.') + '\n'
+	header += tr('Select any packages from the below list that should be installed additionally') + '\n'
 
 	# there are over 15k packages so this needs to be quick
 	preset_packages: list[AvailablePackage | PackageGroup] = []
@@ -224,9 +224,9 @@ def ask_additional_packages_to_install(
 		allow_reset=True,
 		allow_skip=True,
 		multi=True,
-		preview_frame=FrameProperties.max("Package info"),
+		preview_frame=FrameProperties.max('Package info'),
 		preview_style=PreviewStyle.RIGHT,
-		preview_size="auto",
+		preview_size='auto',
 	).run()
 
 	match result.type_:
@@ -242,10 +242,10 @@ def ask_additional_packages_to_install(
 def add_number_of_parallel_downloads(preset: int | None = None) -> int | None:
 	max_recommended = 5
 
-	header = tr("This option enables the number of parallel downloads that can occur during package downloads") + "\n"
-	header += tr("Enter the number of parallel downloads to be enabled.\n\nNote:\n")
-	header += tr(" - Maximum recommended value : {} ( Allows {} parallel downloads at a time )").format(max_recommended, max_recommended) + "\n"
-	header += tr(" - Disable/Default : 0 ( Disables parallel downloading, allows only 1 download at a time )\n")
+	header = tr('This option enables the number of parallel downloads that can occur during package downloads') + '\n'
+	header += tr('Enter the number of parallel downloads to be enabled.\n\nNote:\n')
+	header += tr(' - Maximum recommended value : {} ( Allows {} parallel downloads at a time )').format(max_recommended, max_recommended) + '\n'
+	header += tr(' - Disable/Default : 0 ( Disables parallel downloading, allows only 1 download at a time )\n')
 
 	def validator(s: str) -> str | None:
 		try:
@@ -255,10 +255,10 @@ def add_number_of_parallel_downloads(preset: int | None = None) -> int | None:
 		except Exception:
 			pass
 
-		return tr("Invalid download number")
+		return tr('Invalid download number')
 
 	result = EditMenu(
-		tr("Number downloads"),
+		tr('Number downloads'),
 		header=header,
 		allow_skip=True,
 		allow_reset=True,
@@ -276,23 +276,23 @@ def add_number_of_parallel_downloads(preset: int | None = None) -> int | None:
 		case _:
 			assert_never(result.type_)
 
-	pacman_conf_path = Path("/etc/pacman.conf")
+	pacman_conf_path = Path('/etc/pacman.conf')
 	with pacman_conf_path.open() as f:
-		pacman_conf = f.read().split("\n")
+		pacman_conf = f.read().split('\n')
 
-	with pacman_conf_path.open("w") as fwrite:
+	with pacman_conf_path.open('w') as fwrite:
 		for line in pacman_conf:
-			if "ParallelDownloads" in line:
-				fwrite.write(f"ParallelDownloads = {downloads}\n")
+			if 'ParallelDownloads' in line:
+				fwrite.write(f'ParallelDownloads = {downloads}\n')
 			else:
-				fwrite.write(f"{line}\n")
+				fwrite.write(f'{line}\n')
 
 	return downloads
 
 
 def ask_post_installation() -> PostInstallationAction:
-	header = tr("Installation completed") + "\n\n"
-	header += tr("What would you like to do next?") + "\n"
+	header = tr('Installation completed') + '\n\n'
+	header += tr('What would you like to do next?') + '\n'
 
 	items = [MenuItem(action.value, value=action) for action in PostInstallationAction]
 	group = MenuItemGroup(items)
@@ -308,11 +308,11 @@ def ask_post_installation() -> PostInstallationAction:
 		case ResultType.Selection:
 			return result.get_value()
 		case _:
-			raise ValueError("Post installation action not handled")
+			raise ValueError('Post installation action not handled')
 
 
 def ask_abort() -> None:
-	prompt = tr("Do you really want to abort?") + "\n"
+	prompt = tr('Do you really want to abort?') + '\n'
 	group = MenuItemGroup.yes_no()
 
 	result = SelectMenu[bool](
